pub mod consumers;
pub mod staging;
pub mod handler {
    use std::sync::Arc;

    use super::{
        consumers::{Consumer, PartitionKey, Topic, TopicOffset},
        staging::Staging,
    };

    #[derive(Clone)]
    pub struct Handler {
        staging: Arc<Staging>,
    }

    impl Handler {
        pub fn new(staging: Staging) -> Self {
            Self {
                staging: Arc::new(staging),
            }
        }

        pub fn handle_offset(
            &self,
            topic: &Topic,
            partition_key: &Option<PartitionKey>,
            consumer: &Consumer,
            offset: TopicOffset,
        ) -> anyhow::Result<()> {
            let events = self.staging.get_topic_offset(
                topic,
                partition_key.clone(),
                consumer.offset,
                offset,
            )?;

            // TODO: handle events
            for event in events {
                tracing::trace!("handling event: {:?}", event);
            }

            Ok(())
        }
    }
}
